# Welcome to Vigilant Kit docs

## Table of content
 - [How to install Selenium server & browser drivers](selenium_install.md)
 - [How to start testing with `unittest` library](vigilant_unittest.md) 
 - [How to add custom browser options](browser_options.md)
 - [Access native Selenium WebDriver methods](native_selenium.md)
 - [List of actions](actions.md)

